@@ -28,7 +28,7 @@ waldtest.default <- function(object, ..., vcov = NULL, test = c("Chisq", "F"), n
   nobs0   <- function(x, ...) {
     nobs1 <- if("stats4" %in% loadedNamespaces()) stats4:::nobs else nobs
     nobs2 <- function(x, ...) NROW(residuals(x, ...))
-    rval <- try(nobs1(x, ...))
+    rval <- try(nobs1(x, ...), silent = TRUE)
     if(inherits(rval, "try-error") | is.null(rval)) rval <- nobs2(x, ...)
     return(rval)
   }
